@@ -89,10 +89,10 @@ class FileHandler:
     def __init__(self):
         pass
 
-    def write_to_local_filesystem(self, local_path, content):
-        with open(f"{local_path}/{os.path.basename(content)}", 'wb') as f:
+    def write_to_local_filesystem(self, local_file_path, content):
+        with open(f"{local_file_path}", 'wb') as f:
             f.write(content)
-        logger.success(f"file saved into: {local_path}")
+        logger.success(f"file saved into: {local_file_path}")
 
     def upload_to_bucket(self):
         raise NotImplementedError
